@@ -48,16 +48,18 @@ namespace BOOM {
     enum missing_status { observed = 0, completely_missing, partly_missing };
 
     Data() : missing_flag(observed) {}
-    Data(const Data &rhs) : missing_flag(rhs.missing_flag) {}
+    // When copying Data, the observers should not be copied.
+    Data(const Data &rhs)
+        : missing_flag(rhs.missing_flag),
+          signals_() {}
     virtual Data *clone() const = 0;
-    virtual ~Data() = default;
+    virtual ~Data() {signals_.clear();}
     virtual std::ostream &display(std::ostream &) const = 0;
     missing_status missing() const;
     void set_missing_status(missing_status m);
     void signal() {
-      uint n = signals_.size();
-      for (uint i = 0; i < n; ++i) {
-        signals_[i]();
+      for (auto &it : signals_) {
+        it.second();
       }
     }
     // TODO: This implementation of the observer pattern is broken by
@@ -68,15 +70,22 @@ namespace BOOM {
     // that the observer is active when calling, and remove inactive observers
     // from the set of signals.  This fix will require making changes to all the
     // classes that use the current observer scheme.
-    void add_observer(const std::function<void(void)> &f) {
-      signals_.push_back(f);
+    void add_observer(void *owner, const std::function<void(void)> &f) {
+      signals_.insert(std::make_pair(owner, f));
     }
+
+    void remove_observer(void *owner) {
+      signals_.erase(owner);
+    }
+
+    // Remove all observers.
+    void clear_observers() { signals_.clear(); }
     friend void intrusive_ptr_add_ref(Data *d);
     friend void intrusive_ptr_release(Data *d);
 
    private:
     missing_status missing_flag;
-    std::vector<std::function<void(void)> > signals_;
+    std::multimap<void *, std::function<void(void)>>  signals_;
   };
   //======================================================================
   std::ostream &operator<<(std::ostream &out, const Data &d);
@@ -137,18 +146,23 @@ namespace BOOM {
     VectorData(const VectorData &rhs);
     VectorData *clone() const override;
 
-    uint dim() const { return x.size(); }
+    uint dim() const { return data_.size(); }
     std::ostream &display(std::ostream &out) const override;
 
-    const Vector &value() const override { return x; }
+    const Vector &value() const override { return data_; }
     void set(const Vector &rhs, bool signal_change = true) override;
     virtual void set_element(double value, int position, bool sig = true);
 
+    // Set the contiguous subset of elements from start to start + subset.size()
+    // - 1 with the elements of subset.
+    virtual void set_subset(const Vector &subset, int start,
+                            bool signal = true);
+
     double operator[](uint) const;
     double &operator[](uint);
 
    private:
-    Vector x;
+    Vector data_;
   };
 
   //==========================================================================
