@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2014 Steven L. Scott
 
@@ -19,25 +20,24 @@
 #ifndef BOOM_MULTINOMIAL_LOGIT_COMPLETE_DATA_SUF_HPP_
 #define BOOM_MULTINOMIAL_LOGIT_COMPLETE_DATA_SUF_HPP_
 
-#include <LinAlg/SpdMatrix.hpp>
-#include <Models/Glm/ChoiceData.hpp>
-#include <cpputil/RefCounted.hpp>
+#include "LinAlg/SpdMatrix.hpp"
+#include "Models/Glm/ChoiceData.hpp"
+#include "cpputil/RefCounted.hpp"
 
 namespace BOOM {
   namespace MultinomialLogit {
 
-    class CompleteDataSufficientStatistics
-        : private RefCounted {
+    class CompleteDataSufficientStatistics : private RefCounted {
      public:
-      CompleteDataSufficientStatistics(uint dim);
-      CompleteDataSufficientStatistics * clone() const;
+      explicit CompleteDataSufficientStatistics(uint dim);
+      CompleteDataSufficientStatistics *clone() const;
 
       void clear();
       void update(const ChoiceData &dp, const Vector &wgts, const Vector &u);
       void combine(const CompleteDataSufficientStatistics &rhs);
 
-      const SpdMatrix & xtwx()const;
-      const Vector & xtwu()const;
+      const SpdMatrix &xtwx() const;
+      const Vector &xtwu() const;
       double weighted_sum_of_squares() const;
 
      private:
@@ -47,12 +47,15 @@ namespace BOOM {
       double weighted_sum_of_squares_;
 
       friend void intrusive_ptr_add_ref(CompleteDataSufficientStatistics *w) {
-        w->up_count(); }
+        w->up_count();
+      }
       friend void intrusive_ptr_release(CompleteDataSufficientStatistics *w) {
-        w->down_count(); if (w->ref_count() == 0) delete w; }
+        w->down_count();
+        if (w->ref_count() == 0) delete w;
+      }
     };
 
   }  // namespace MultinomialLogit
 }  // namespace BOOM
 
-#endif // BOOM_MULTINOMIAL_LOGIT_COMPLETE_DATA_SUF_HPP_
+#endif  // BOOM_MULTINOMIAL_LOGIT_COMPLETE_DATA_SUF_HPP_
