@@ -84,7 +84,7 @@ double qbinom(double p, double n, double pr, int lower_tail, int log_p)
         if (p == 1.) return n;
     }
     /* temporary hack --- FIXME --- */
-    if (p + 1.01*numeric_limits<double>::epsilon() >= 1.) return n;
+    if (p + 1.01*std::numeric_limits<double>::epsilon() >= 1.) return n;
 
     /* y := approx.value (Cornish-Fisher expansion) :  */
     z = qnorm(p, 0., 1., /*lower_tail*/true, /*log_p*/false);
@@ -94,7 +94,7 @@ double qbinom(double p, double n, double pr, int lower_tail, int log_p)
     z = pbinom(y, n, pr, /*lower_tail*/true, /*log_p*/false);
 
     /* fuzz to ensure left continuity: */
-    p *= 1 - 64*numeric_limits<double>::epsilon();
+    p *= 1 - 64*std::numeric_limits<double>::epsilon();
 
 /*-- Fixme, here y can be way off --
   should use interval search instead of primitive stepping down or up */
